@@ -1,14 +1,6 @@
-#!/usr/bin/env perl
-
 use strict;
 use warnings;
 
-use feature qw(say);
-
-our $VERSION = "0.01";
-
-use Data::Dumper qw(Dumper);
-
 =encoding utf-8
 
 =head1 NAME
