@@ -7,16 +7,21 @@ use feature qw(say);
 
 our $VERSION = "0.01";
 my @here = ( <<"FIRST", <<'SECOND', <<END);
-require HERE;
-use HERE::Somthing;
+the inside of here document must be excluded from parsing
+    require FIRST;
+    use HERE::FIRST;
 FIRST
+here is still inside..
     require SECOND;
     use HERE::Second;
 SECOND
+here is still inside..
     require End;
     use HERE::End;
 END
 
+# now it is outside
+
 require Dummy;    # does not exist anywhere
 
 exit;
