@@ -1,24 +1,20 @@
-#!/usr/bin/env perl
-
 use strict;
 use warnings;
 
-use feature qw(say);
-
-our $VERSION = "0.01";
+# the all iside of nested if sholud NOT to be parsed
 
 if (1) {
-    require Require::With::If;    # not parsed
+    require Require::With::If;    # braced
 }
 
 if (1) {    # comment
-    require Require::With::If::Commented;    # not parsed
+    require Require::With::If::Commented;    # double braced
 }    # comment
 
 if (1) {    # first
     if (1) {    # second
         if (1) {    # third
-            require Require::With::Nested::If;    # not parsed
+            require Require::With::Nested::If;    # triple braced
         }
     }
 }
